<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AnalyzeGameWidget</name>
    <message>
        <source>Win</source>
        <translation>Gewinn</translation>
    </message>
    <message>
        <source>Loss</source>
        <translation>Verlust</translation>
    </message>
    <message>
        <source>Running game analysis...</source>
        <translation>Spiel wird analysiert ...</translation>
    </message>
</context>
<context>
    <name>AnalyzeGameWindow</name>
    <message>
        <source>Game Analysis</source>
        <translation>Spielanalyse</translation>
    </message>
</context>
<context>
    <name>AnalyzeSpeedDialog</name>
    <message>
        <source>Fast</source>
        <translation>Schnell</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Langsam</translation>
    </message>
    <message>
        <source>Analysis speed:</source>
        <translation>Analysegeschwindigkeit:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>About Pentobi</source>
        <translation>Über Pentobi</translation>
    </message>
    <message>
        <source>Next &amp;Color</source>
        <translation>Nächste &amp;Farbe</translation>
    </message>
    <message>
        <source>S&amp;etup Mode</source>
        <translation>&amp;Stellungsaufbau</translation>
    </message>
    <message>
        <source>Could not read file &apos;%1&apos;</source>
        <translation>Datei &apos;%1&apos; konnte nicht gelesen werden</translation>
    </message>
    <message>
        <source>The file is not a valid Blokus SGF file.</source>
        <translation>Die Datei ist keine gültige Blokus-SGF-Datei.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Diesen Teilbaum abschneiden?</translation>
    </message>
    <message>
        <source>This position and all following moves and variations will be removed from the game tree.</source>
        <translation>Diese Brettstellung und alle folgenden Züge und Varianten werden aus dem Spielbaum entfernt.</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Abschneiden</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Kindknoten abschneiden?</translation>
    </message>
    <message>
        <source>All following moves and variations will be removed from the game tree.</source>
        <translation>Alle folgenden Züge und Varianten werden aus dem Spielbaum entfernt.</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Kindknoten abschneiden</translation>
    </message>
    <message>
        <source>Could not delete %1</source>
        <translation>%1 konnte nicht gelöscht werden</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Gewertetes Spiel</translation>
    </message>
    <message>
        <source>Continuing unfinished rated game.</source>
        <translation>Unbeendetes gewertetes Spiel wird fortgesetzt.</translation>
    </message>
    <message>
        <source>You play %1 in this game.</source>
        <translation>Sie spielen %1 in diesem Spiel.</translation>
    </message>
    <message>
        <source>&amp;copy; 2011&amp;ndash;%1 Markus Enzenberger</source>
        <translation>&amp;copy; 2011&amp;ndash;%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Analyze Game</source>
        <translation>Spiel analysieren</translation>
    </message>
    <message>
        <source>&amp;About Pentobi</source>
        <translation>Über &amp;Pentobi</translation>
    </message>
    <message>
        <source>&amp;Analyze Game...</source>
        <translation>Spiel &amp;analysieren ...</translation>
    </message>
    <message>
        <source>B&amp;ackward</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>Einen Zug zurück gehen</translation>
    </message>
    <message>
        <source>Back to &amp;Main Variation</source>
        <translation>Zurück zu Hau&amp;ptvariante</translation>
    </message>
    <message>
        <source>&amp;Bad</source>
        <translation>Schl&amp;echt</translation>
    </message>
    <message>
        <source>&amp;Beginning</source>
        <translation>&amp;Anfang</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>Zum Anfang des Spiels gehen</translation>
    </message>
    <message>
        <source>Beginning of Bran&amp;ch</source>
        <translation>Anfang der Verz&amp;weigung</translation>
    </message>
    <message>
        <source>Clear Piece</source>
        <translation>Spielstein löschen</translation>
    </message>
    <message>
        <source>&amp;Computer Colors</source>
        <translation>&amp;Computer-Farben</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Die vom Computer gespielten Farben festlegen</translation>
    </message>
    <message>
        <source>C&amp;oordinates</source>
        <translation>K&amp;oordinaten</translation>
    </message>
    <message>
        <source>&amp;Delete All Variations</source>
        <translation>Alle &amp;Varianten löschen</translation>
    </message>
    <message>
        <source>&amp;Doubtful</source>
        <translation>&amp;Zweifelhaft</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Ende</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>Zum Ende der Züge gehen</translation>
    </message>
    <message>
        <source>&amp;ASCII Art</source>
        <translation>&amp;ASCII-Art</translation>
    </message>
    <message>
        <source>I&amp;mage</source>
        <translation>&amp;Grafik</translation>
    </message>
    <message>
        <source>&amp;Find Move</source>
        <translation>Zug fin&amp;den</translation>
    </message>
    <message>
        <source>Flip Horizontally</source>
        <translation>Waagrecht umdrehen</translation>
    </message>
    <message>
        <source>Flip Vertically</source>
        <translation>Senkrecht umdrehen</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Einen Zug vorwärts gehen</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Voll&amp;bild</translation>
    </message>
    <message>
        <source>Ga&amp;me Info</source>
        <translation>Spielinf&amp;ormation</translation>
    </message>
    <message>
        <source>St&amp;op</source>
        <translation>St&amp;opp</translation>
    </message>
    <message>
        <source>&amp;Duo</source>
        <translation>&amp;Duo</translation>
    </message>
    <message>
        <source>&amp;Good</source>
        <translation>&amp;Gut</translation>
    </message>
    <message>
        <source>Game analysis is only possible in the main variation.</source>
        <translation>Spielanalyse ist nur in der Hauptvariante möglich.</translation>
    </message>
    <message>
        <source>Find Next &amp;Comment</source>
        <translation>Nächsten &amp;Kommentar finden</translation>
    </message>
    <message>
        <source>&amp;Go to Move...</source>
        <translation>&amp;Gehe zu Zug ...</translation>
    </message>
    <message>
        <source>Pentobi &amp;Help</source>
        <translation>Pentobi-&amp;Hilfe</translation>
    </message>
    <message>
        <source>I&amp;nteresting</source>
        <translation>I&amp;nteressant</translation>
    </message>
    <message>
        <source>&amp;Keep Only Position</source>
        <translation>Nur &amp;Brettstellung behalten</translation>
    </message>
    <message>
        <source>Keep Only &amp;Subtree</source>
        <translation>Nur &amp;Teilbaum behalten</translation>
    </message>
    <message>
        <source>Leave Fullscreen</source>
        <translation>Vollbild verlassen</translation>
    </message>
    <message>
        <source>M&amp;ake Main Variation</source>
        <translation>Zu &amp;Hauptvariante machen</translation>
    </message>
    <message>
        <source>Move Variation D&amp;own</source>
        <translation>Variante nach &amp;unten schieben</translation>
    </message>
    <message>
        <source>Move Variation &amp;Up</source>
        <translation>Variante nach &amp;oben schieben</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>&amp;6</source>
        <translation>&amp;6</translation>
    </message>
    <message>
        <source>&amp;7</source>
        <translation>&amp;7</translation>
    </message>
    <message>
        <source>&amp;8</source>
        <translation>&amp;8</translation>
    </message>
    <message>
        <source>&amp;None</source>
        <comment>move numbers</comment>
        <translation>&amp;Keine</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Nächster Spielstein</translation>
    </message>
    <message>
        <source>&amp;Next Variation</source>
        <translation>&amp;Nächste Variante</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>Zur nächsten Variante gehen</translation>
    </message>
    <message>
        <source>&amp;Rated Game</source>
        <translation>Ge&amp;wertetes Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>Start a new game</source>
        <translation>Ein neues Spiel beginnen</translation>
    </message>
    <message>
        <source>N&amp;one</source>
        <comment>move annotation</comment>
        <translation>&amp;Keine</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Öffn&amp;en ...</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spielen</translation>
    </message>
    <message>
        <source>Play &amp;Single Move</source>
        <translation>&amp;Einzelnen Zug spielen</translation>
    </message>
    <message>
        <source>Previous Piece</source>
        <translation>Vorheriger Spielstein</translation>
    </message>
    <message>
        <source>&amp;Previous Variation</source>
        <translation>Vor&amp;herige Variante</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>Zur vorherigen Variante gehen</translation>
    </message>
    <message>
        <source>Rotate Anticlockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate Clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter ...</translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation>&amp;Kommentar</translation>
    </message>
    <message>
        <source>&amp;Rating</source>
        <translation>&amp;Wertung</translation>
    </message>
    <message>
        <source>&amp;No Text</source>
        <translation>&amp;Kein Text</translation>
    </message>
    <message>
        <source>Text &amp;Beside Icons</source>
        <translation>Text n&amp;eben Symbolen</translation>
    </message>
    <message>
        <source>Text Bel&amp;ow Icons</source>
        <translation>Text &amp;unter Symbolen</translation>
    </message>
    <message>
        <source>&amp;Text Only</source>
        <translation>&amp;Nur Text</translation>
    </message>
    <message>
        <source>&amp;System Default</source>
        <translation>&amp;Systemvorgabe</translation>
    </message>
    <message>
        <source>&amp;Truncate</source>
        <translation>&amp;Abschneiden</translation>
    </message>
    <message>
        <source>Truncate C&amp;hildren</source>
        <translation>&amp;Kindknoten abschneiden</translation>
    </message>
    <message>
        <source>Show &amp;Variations</source>
        <translation>&amp;Varianten zeigen</translation>
    </message>
    <message>
        <source>&amp;Undo Move</source>
        <translation>Zug rück&amp;gängig</translation>
    </message>
    <message>
        <source>V&amp;ery Bad</source>
        <translation>Seh&amp;r schlecht</translation>
    </message>
    <message>
        <source>&amp;Very Good</source>
        <translation>&amp;Sehr gut</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Move Annotation</source>
        <translation>&amp;Zugkommentierung</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Toolbar T&amp;ext</source>
        <translation>Werkzeugleistent&amp;ext</translation>
    </message>
    <message>
        <source>&amp;Computer</source>
        <translation>&amp;Computer</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>E&amp;xtras</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Alle Varianten löschen?</translation>
    </message>
    <message>
        <source>All variations but the main variation will be removed from the game tree.</source>
        <translation>Alle Varianten außer der Hauptvariante werden aus dem Spielbaum entfernt.</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Varianten löschen</translation>
    </message>
    <message>
        <source>&amp;Toolbar</source>
        <translation>&amp;Werkzeugleiste</translation>
    </message>
    <message>
        <source>Text files (*.txt);;All files (*)</source>
        <translation>Textdateien (*.txt);;Alle Dateien (*)</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Kein Kommentar gefunden</translation>
    </message>
    <message>
        <source>Blokus games (*.blksgf);;All files (*)</source>
        <translation>Blokus-Partien (*.blksgf);;Alle Dateien (*)</translation>
    </message>
    <message>
        <source>Move number:</source>
        <translation>Zugnummer:</translation>
    </message>
    <message>
        <source>Go to Move</source>
        <translation>Gehe zu Zug</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Nur Brettstellung behalten?</translation>
    </message>
    <message>
        <source>All previous and following moves and variations will be removed from the game tree.</source>
        <translation>Alle vorhergehenden und nachfolgenden Züge und Varianten werden aus dem Spielbaum entfernt.</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Nur Teilbaum behalten?</translation>
    </message>
    <message>
        <source>All previous moves and variations will be removed from the game tree.</source>
        <translation>Alle vorhergehenden Züge und Varianten werden aus dem Spielbaum entfernt.</translation>
    </message>
    <message>
        <source>Start rated game?</source>
        <translation>Gewertetes Spiel beginnen?</translation>
    </message>
    <message>
        <source>In this game, you play %1 against Pentobi level&amp;nbsp;%2.</source>
        <translation>In diesem Spiel spielen Sie %1 gegen Pentobi Spielstufe&amp;nbsp;%2.</translation>
    </message>
    <message>
        <source>&amp;Start Game</source>
        <translation>&amp;Spiel beginnen</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>The first argument is the version of Pentobi</extracomment>
        <translation>Pentobi %1 (Stufe %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Mensch</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>The file could not be saved.</source>
        <translation>Die Datei konnte nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>%1: %2</source>
        <extracomment>Error message if file cannot be saved. %1 is replaced by the file name, %2 by the error message of the operating system.</extracomment>
        <translation>%1: %2</translation>
    </message>
    <message>
        <source>Untitled Game.blksgf</source>
        <translation>Unbenanntes Spiel.blksgf</translation>
    </message>
    <message>
        <source>Untitled Game %1.blksgf</source>
        <translation>Unbenanntes Spiel %1.blksgf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Pentobi</source>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus.</source>
        <translation>Computer-Gegner für das Brettspiel Blokus.</translation>
    </message>
    <message>
        <source>The file has been modified.</source>
        <translation>Die Datei wurde geändert.</translation>
    </message>
    <message>
        <source>Do you want to save your changes?</source>
        <translation>Änderungen speichern?</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t Save</source>
        <translation>&amp;Nicht speichern</translation>
    </message>
    <message>
        <source>The current game is not finished.</source>
        <translation>Das gegenwärtige Spiel ist nicht beendet.</translation>
    </message>
    <message>
        <source>Do you want to abort the game?</source>
        <translation>Möchten Sie das Spiel verwerfen?</translation>
    </message>
    <message>
        <source>&amp;Abort Game</source>
        <translation>Spiel &amp;verwerfen</translation>
    </message>
    <message>
        <source>&amp;9</source>
        <translation>&amp;9</translation>
    </message>
    <message>
        <source>&amp;All with Number</source>
        <translation>&amp;Alle mit Nummer</translation>
    </message>
    <message>
        <source>Last with &amp;Dot</source>
        <translation>Letzter mit &amp;Punkt</translation>
    </message>
    <message>
        <source>&amp;Last with Number</source>
        <translation>Letzter mit &amp;Nummer</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Ein gewertetes Spiel beginnen</translation>
    </message>
    <message>
        <source>Classic (&amp;3 Players)</source>
        <translation>Klassisch (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>Game &amp;Variant</source>
        <translation>Spiel&amp;variante</translation>
    </message>
    <message>
        <source>Open R&amp;ecent</source>
        <translation>&amp;Zuletzt benutzte Dateien</translation>
    </message>
    <message>
        <source>E&amp;xport</source>
        <translation>E&amp;xportieren</translation>
    </message>
    <message>
        <source>G&amp;o</source>
        <translation>&amp;Gehe zu</translation>
    </message>
    <message>
        <source>&amp;Move Marking</source>
        <translation>&amp;Zugmarkierung</translation>
    </message>
    <message>
        <source>Export Image</source>
        <translation>Grafik exportieren</translation>
    </message>
    <message>
        <source>Image size:</source>
        <translation>Bildgröße:</translation>
    </message>
    <message>
        <source>The end of the tree was reached.</source>
        <translation>Das Ende des Spielbaums wurde erreicht.</translation>
    </message>
    <message>
        <source>Continue the search from the start of the tree?</source>
        <translation>Die Suche vom Beginn des Spielbaums fortsetzen?</translation>
    </message>
    <message>
        <source>Continue From Start</source>
        <translation>Suche vom Beginn fortsetzen</translation>
    </message>
    <message>
        <source>Show &amp;Rating</source>
        <translation>&amp;Wertung zeigen</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-Hilfe</translation>
    </message>
    <message>
        <source>Keep Only Position</source>
        <translation>Nur Brettstellung behalten</translation>
    </message>
    <message>
        <source>Keep Only Subtree</source>
        <translation>Nur Teilbaum behalten</translation>
    </message>
    <message>
        <source>[*]%1</source>
        <translation>[*]%1</translation>
    </message>
    <message>
        <source>Setup mode cannot be used if moves have been played.</source>
        <translation>Stellungsaufbau-Modus kann nicht benutzt werden, wenn Züge gespielt wurden.</translation>
    </message>
    <message>
        <source>Setup mode</source>
        <translation>Stellungsaufbau</translation>
    </message>
    <message>
        <source>The game ends in a tie.</source>
        <translation>Das Spiel endet in einem Unentschieden.</translation>
    </message>
    <message>
        <source>The game ends in a tie between all colors.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen allen Farben.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue, Yellow and Red.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau, Gelb und Rot.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue, Yellow and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau, Gelb und Grün.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue, Red and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau, Rot und Grün.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Yellow, Red and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Gelb, Rot und Grün.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue and Yellow.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau und Gelb.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue and Red.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau und Rot.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Blue and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Blau und Grün.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Yellow and Red.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Gelb und Rot.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Yellow and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Gelb und Grün.</translation>
    </message>
    <message>
        <source>The game ends in a tie between Red and Green.</source>
        <translation>Das Spiel endet in einem Unentschieden zwischen Rot und Grün.</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Blau gewinnt.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Gelb gewinnt.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rot gewinnt.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Grün gewinnt.</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 erhöht.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Ihre Wertung bleibt auf %1.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 erniedrigt.</translation>
    </message>
    <message>
        <source>Error in file &apos;%1&apos;</source>
        <translation>Fehler in Datei &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Move %1</source>
        <translation>Zug %1</translation>
    </message>
    <message numerus="yes">
        <source>%n move(s)</source>
        <translation>
            <numerusform>%n Zug</numerusform>
            <numerusform>%n Züge</numerusform>
        </translation>
    </message>
    <message>
        <source>Move %1 of %2</source>
        <translation>Zug %1 von %2</translation>
    </message>
    <message>
        <source>Move %1 of %2 in variation %3</source>
        <translation>Zug %1 von %2 in Variante %3</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Den Computer die gegenwärtige Farbe weiterspielen lassen</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Den Computer die gegenwärtige Farbe spielen lassen</translation>
    </message>
    <message>
        <source>Classic (&amp;4 Players)</source>
        <translation>Klassisch (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>J&amp;unior</source>
        <translation>J&amp;unior</translation>
    </message>
    <message>
        <source>Classic (&amp;2 Players)</source>
        <translation>Klassisch (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (&amp;2 Players)</source>
        <translation>Nexos (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (&amp;4 Players)</source>
        <translation>Nexos (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (&amp;2 Players)</source>
        <translation>Trigon (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (&amp;3 Players)</source>
        <translation>Trigon (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (&amp;4 Players)</source>
        <translation>Trigon (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Classic</source>
        <translation>&amp;Klassisch</translation>
    </message>
    <message>
        <source>&amp;Trigon</source>
        <translation>&amp;Trigon</translation>
    </message>
    <message>
        <source>&amp;Nexos</source>
        <translation>&amp;Nexos</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Blau gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue wins with %1 points.</source>
        <translation>Blau gewinnt mit %1 Punkten.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Green wins with %1 points.</source>
        <translation>Grün gewinnt mit %1 Punkten.</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Blau/Rot gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %1 points.</source>
        <translation>Blau/Rot gewinnt mit %1 Punkten.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Gelb/Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %1 points.</source>
        <translation>Gelb/Grün gewinnt mit %1 Punkten.</translation>
    </message>
    <message>
        <source>Callisto (&amp;2 Players)</source>
        <translation>Callisto (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (&amp;3 Players)</source>
        <translation>Callisto (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (&amp;4 Players)</source>
        <translation>Callisto (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>C&amp;allisto</source>
        <translation>&amp;Callisto</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <translation>Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <translation>Gelb/Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <translation>Rot gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <translation>Gelb gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 4 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 2 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 3 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Duo)</source>
        <translation>Spielst&amp;ufe (Duo)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 4 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 2 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 3 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Junior)</source>
        <translation>Spielst&amp;ufe (Junior)</translation>
    </message>
    <message>
        <source>&amp;Level (Nexos, 4 Players)</source>
        <translation>Spielst&amp;ufe (Nexos, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Nexos, 2 Players)</source>
        <translation>Spielst&amp;ufe (Nexos, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 4 Players)</source>
        <translation>Spielst&amp;ufe (Callisto, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 2 Players)</source>
        <translation>Spielst&amp;ufe (Callisto, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 3 Players)</source>
        <translation>Spielst&amp;ufe (Callisto, 3 Spieler)</translation>
    </message>
    <message>
        <source>Computer is thinking... (up to %1 seconds remaining)</source>
        <translation>Computer denkt ... (maximal %1 Sekunden verbleibend)</translation>
    </message>
    <message>
        <source>Computer is thinking... (up to %1 minutes remaining)</source>
        <translation>Computer denkt ... (maximal %1 Minuten verbleibend)</translation>
    </message>
    <message>
        <source>Computer is thinking...</source>
        <translation>Computer denkt ...</translation>
    </message>
</context>
<context>
    <name>RatedGamesList</name>
    <message>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Your Color</source>
        <translation>Ihre Farbe</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>Result</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Gewinn</translation>
    </message>
    <message>
        <source>Tie</source>
        <translation>Unentschieden</translation>
    </message>
    <message>
        <source>Loss</source>
        <translation>Verlust</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Rating</source>
        <translation>Wertung</translation>
    </message>
    <message>
        <source>Your rating:</source>
        <translation>Ihre Wertung:</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Spielvariante:</translation>
    </message>
    <message>
        <source>Number rated games:</source>
        <translation>Anzahl gewertete Spiele:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Beste frühere Wertung:</translation>
    </message>
    <message>
        <source>Recent games:</source>
        <translation>Zuletzt gespielte Spiele:</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Clear rating and delete rating history?</source>
        <translation>Wertung und Wertungsentwicklung löschen?</translation>
    </message>
    <message>
        <source>Clear rating</source>
        <translation>Wertung löschen</translation>
    </message>
    <message>
        <source>Classic (4 players)</source>
        <translation>Klassisch (4 Spieler)</translation>
    </message>
    <message>
        <source>Classic (2 players)</source>
        <translation>Klassisch (2 Spieler)</translation>
    </message>
    <message>
        <source>Classic (3 players)</source>
        <translation>Klassisch (3 Spieler)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Trigon (4 players)</source>
        <translation>Trigon (4 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (2 players)</source>
        <translation>Trigon (2 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (3 players)</source>
        <translation>Trigon (3 Spieler)</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Aktuelle Entwicklung:</translation>
    </message>
    <message>
        <source>Nexos (4 players)</source>
        <translation>Nexos (4 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (2 players)</source>
        <translation>Nexos (2 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (4 players)</source>
        <translation>Callisto (4 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (2 players)</source>
        <translation>Callisto (2 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (3 players)</source>
        <translation>Callisto (3 Spieler)</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Not enough memory.</source>
        <translation>Nicht genügend Speicher.</translation>
    </message>
    <message>
        <source>Pentobi</source>
        <translation>Pentobi</translation>
    </message>
</context>
</TS>
